Enum Request
#[non_exhaustive]pub enum Request {
Commit,
Stop,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Commit
all requests about the workspaces have been sent
The client must send this request after it has finished sending other requests. The compositor must process a series of requests preceding a commit request atomically.
This allows changes to the workspace properties to be seen as atomic, even if they happen via multiple events, and even if they involve multiple ext_workspace_handle_v1 objects, for example, deactivating one workspace and activating another.
Stop
stop sending events
Indicates the client no longer wishes to receive events for new workspace groups. However the compositor may emit further workspace events, until the finished event is emitted. The compositor is expected to send the finished event eventually once the stop request has been processed.
The client must not send any requests after this one, doing so will raise a wl_display invalid_object error.
Implementations