Struct ExtWorkspaceManagerV1
pub struct ExtWorkspaceManagerV1 { /* private fields */ }wayland and Linux only.Expand description
list and control workspaces
Workspaces, also called virtual desktops, are groups of surfaces. A compositor with a concept of workspaces may only show some such groups of surfaces (those of ‘active’ workspaces) at a time. ‘Activating’ a workspace is a request for the compositor to display that workspace’s surfaces as normal, whereas the compositor may hide or otherwise de-emphasise surfaces that are associated only with ‘inactive’ workspaces. Workspaces are grouped by which sets of outputs they correspond to, and may contain surfaces only from those outputs. In this way, it is possible for each output to have its own set of workspaces, or for all outputs (or any other arbitrary grouping) to share workspaces. Compositors may optionally conceptually arrange each group of workspaces in an N-dimensional grid.
The purpose of this protocol is to enable the creation of taskbars and docks by providing them with a list of workspaces and their properties, and allowing them to activate and deactivate workspaces.
After a client binds the ext_workspace_manager_v1, each workspace will be sent via the workspace event.
See also the Request enum for this interface.
Implementations
impl ExtWorkspaceManagerV1
impl ExtWorkspaceManagerV1
pub fn workspace_group(&self, workspace_group: &ExtWorkspaceGroupHandleV1)
pub fn workspace_group(&self, workspace_group: &ExtWorkspaceGroupHandleV1)
a workspace group has been created
This event is emitted whenever a new workspace group has been created.
All initial details of the workspace group (outputs) will be sent immediately after this event via the corresponding events in ext_workspace_group_handle_v1 and ext_workspace_handle_v1.
pub fn workspace(&self, workspace: &ExtWorkspaceHandleV1)
pub fn workspace(&self, workspace: &ExtWorkspaceHandleV1)
workspace has been created
This event is emitted whenever a new workspace has been created.
All initial details of the workspace (name, coordinates, state) will be sent immediately after this event via the corresponding events in ext_workspace_handle_v1.
Workspaces start off unassigned to any workspace group.
pub fn done(&self)
pub fn done(&self)
all information about the workspaces and workspace groups has been sent
This event is sent after all changes in all workspaces and workspace groups have been sent.
This allows changes to one or more ext_workspace_group_handle_v1 properties and ext_workspace_handle_v1 properties to be seen as atomic, even if they happen via multiple events. In particular, an output moving from one workspace group to another sends an output_enter event and an output_leave event to the two ext_workspace_group_handle_v1 objects in question. The compositor sends the done event only after updating the output information in both workspace groups.
pub fn finished(&self)
pub fn finished(&self)
the compositor has finished with the workspace_manager
This event indicates that the compositor is done sending events to the ext_workspace_manager_v1. The server will destroy the object immediately after sending this request.